@@ -1,3 +1,4 @@
+/* $XFree86: xc/programs/twm/resize.c,v 1.11 2007/10/10 00:31:39 tsi Exp $ */
 /*****************************************************************************/
 /*
 
@@ -58,7 +59,6 @@ in this Software without prior written authorization from The Open Group.
  *
  ***********************************************************************/
 
-/* $XFree86: xc/programs/twm/resize.c,v 1.10 2005/07/20 00:32:38 dawes Exp $ */
 
 #include <stdio.h>
 #include "twm.h"
@@ -94,7 +94,7 @@ static int last_width;
 static int last_height;
 
 
-static void 
+static void
 do_auto_clamp (TwmWindow *tmp_win, XEvent *evp)
 {
     Window junkRoot;
@@ -117,9 +117,9 @@ do_auto_clamp (TwmWindow *tmp_win, XEvent *evp)
     }
 
     h = ((x - dragx) / (dragWidth < 3 ? 1 : (dragWidth / 3)));
-    v = ((y - dragy - tmp_win->title_height) / 
+    v = ((y - dragy - tmp_win->title_height) /
 	 (dragHeight < 3 ? 1 : (dragHeight / 3)));
-	
+
     if (h <= 0) {
 	clampLeft = 1;
 	clampDX = (x - dragx);
@@ -152,10 +152,7 @@ do_auto_clamp (TwmWindow *tmp_win, XEvent *evp)
  */
 
 void
-StartResize(evp, tmp_win, fromtitlebar)
-XEvent *evp;
-TwmWindow *tmp_win;
-Bool fromtitlebar;
+StartResize(XEvent *evp, TwmWindow *tmp_win, Bool fromtitlebar)
 {
     Window      junkRoot;
     unsigned int junkbw, junkDepth;
@@ -163,14 +160,14 @@ Bool fromtitlebar;
     ResizeWindow = tmp_win->frame;
     XGrabServer(dpy);
     XGrabPointer(dpy, Scr->Root, True,
-        ButtonPressMask | ButtonReleaseMask |
+	ButtonPressMask | ButtonReleaseMask |
 	ButtonMotionMask | PointerMotionHintMask,
-        GrabModeAsync, GrabModeAsync,
-        Scr->Root, Scr->ResizeCursor, CurrentTime);
+	GrabModeAsync, GrabModeAsync,
+	Scr->Root, Scr->ResizeCursor, CurrentTime);
 
     XGetGeometry(dpy, (Drawable) tmp_win->frame, &junkRoot,
-        &dragx, &dragy, (unsigned int *)&dragWidth, (unsigned int *)&dragHeight, &junkbw,
-                 &junkDepth);
+	&dragx, &dragy, (unsigned int *)&dragWidth, (unsigned int *)&dragHeight, &junkbw,
+		 &junkDepth);
     dragx += tmp_win->frame_bw;
     dragy += tmp_win->frame_bw;
     origx = dragx;
@@ -184,7 +181,7 @@ Bool fromtitlebar;
 
     Scr->SizeStringOffset = SIZE_HINDENT;
     XResizeWindow (dpy, Scr->SizeWindow,
-		   Scr->SizeStringWidth + SIZE_HINDENT * 2, 
+		   Scr->SizeStringWidth + SIZE_HINDENT * 2,
 		   Scr->SizeFont.height + SIZE_VINDENT * 2);
     XMapRaised(dpy, Scr->SizeWindow);
     InstallRootColormap();
@@ -200,15 +197,13 @@ Bool fromtitlebar;
 
 
 void
-MenuStartResize(tmp_win, x, y, w, h)
-TwmWindow *tmp_win;
-int x, y, w, h;
+MenuStartResize(TwmWindow *tmp_win, int x, int y, int w, int h)
 {
     XGrabServer(dpy);
     XGrabPointer(dpy, Scr->Root, True,
-        ButtonPressMask | ButtonMotionMask | PointerMotionMask,
-        GrabModeAsync, GrabModeAsync,
-        Scr->Root, Scr->ResizeCursor, CurrentTime);
+	ButtonPressMask | ButtonMotionMask | PointerMotionMask,
+	GrabModeAsync, GrabModeAsync,
+	Scr->Root, Scr->ResizeCursor, CurrentTime);
     dragx = x + tmp_win->frame_bw;
     dragy = y + tmp_win->frame_bw;
     origx = dragx;
@@ -220,12 +215,12 @@ int x, y, w, h;
     last_height = 0;
     Scr->SizeStringOffset = SIZE_HINDENT;
     XResizeWindow (dpy, Scr->SizeWindow,
-		   Scr->SizeStringWidth + SIZE_HINDENT * 2, 
+		   Scr->SizeStringWidth + SIZE_HINDENT * 2,
 		   Scr->SizeFont.height + SIZE_VINDENT * 2);
     XMapRaised(dpy, Scr->SizeWindow);
     DisplaySize(tmp_win, origWidth, origHeight);
     MoveOutline (Scr->Root, dragx - tmp_win->frame_bw,
-		 dragy - tmp_win->frame_bw, 
+		 dragy - tmp_win->frame_bw,
 		 dragWidth + 2 * tmp_win->frame_bw,
 		 dragHeight + 2 * tmp_win->frame_bw,
 		 tmp_win->frame_bw, tmp_win->title_height);
@@ -243,15 +238,13 @@ int x, y, w, h;
  */
 
 void
-AddStartResize(tmp_win, x, y, w, h)
-TwmWindow *tmp_win;
-int x, y, w, h;
+AddStartResize(TwmWindow *tmp_win, int x, int y, int w, int h)
 {
     XGrabServer(dpy);
     XGrabPointer(dpy, Scr->Root, True,
-        ButtonReleaseMask | ButtonMotionMask | PointerMotionHintMask,
-        GrabModeAsync, GrabModeAsync,
-        Scr->Root, Scr->ResizeCursor, CurrentTime);
+	ButtonReleaseMask | ButtonMotionMask | PointerMotionHintMask,
+	GrabModeAsync, GrabModeAsync,
+	Scr->Root, Scr->ResizeCursor, CurrentTime);
 
     dragx = x + tmp_win->frame_bw;
     dragy = y + tmp_win->frame_bw;
@@ -273,10 +266,7 @@ int x, y, w, h;
 
 
 void
-MenuDoResize(x_root, y_root, tmp_win)
-int x_root;
-int y_root;
-TwmWindow *tmp_win;
+MenuDoResize(int x_root, int y_root, TwmWindow *tmp_win)
 {
     int action;
 
@@ -286,91 +276,91 @@ TwmWindow *tmp_win;
     y_root -= clampDY;
 
     if (clampTop) {
-        int         delta = y_root - dragy;
-        if (dragHeight - delta < MINHEIGHT) {
-            delta = dragHeight - MINHEIGHT;
-            clampTop = 0;
-        }
-        dragy += delta;
-        dragHeight -= delta;
-        action = 1;
+	int         delta = y_root - dragy;
+	if (dragHeight - delta < MINHEIGHT) {
+	    delta = dragHeight - MINHEIGHT;
+	    clampTop = 0;
+	}
+	dragy += delta;
+	dragHeight -= delta;
+	action = 1;
     }
     else if (y_root <= dragy/* ||
-             y_root == findRootInfo(root)->rooty*/) {
-        dragy = y_root;
-        dragHeight = origy + origHeight -
-            y_root;
-        clampBottom = 0;
-        clampTop = 1;
+	     y_root == findRootInfo(root)->rooty*/) {
+	dragy = y_root;
+	dragHeight = origy + origHeight -
+	    y_root;
+	clampBottom = 0;
+	clampTop = 1;
 	clampDY = 0;
-        action = 1;
+	action = 1;
     }
     if (clampLeft) {
-        int         delta = x_root - dragx;
-        if (dragWidth - delta < MINWIDTH) {
-            delta = dragWidth - MINWIDTH;
-            clampLeft = 0;
-        }
-        dragx += delta;
-        dragWidth -= delta;
-        action = 1;
+	int         delta = x_root - dragx;
+	if (dragWidth - delta < MINWIDTH) {
+	    delta = dragWidth - MINWIDTH;
+	    clampLeft = 0;
+	}
+	dragx += delta;
+	dragWidth -= delta;
+	action = 1;
     }
     else if (x_root <= dragx/* ||
-             x_root == findRootInfo(root)->rootx*/) {
-        dragx = x_root;
-        dragWidth = origx + origWidth -
-            x_root;
-        clampRight = 0;
-        clampLeft = 1;
+	     x_root == findRootInfo(root)->rootx*/) {
+	dragx = x_root;
+	dragWidth = origx + origWidth -
+	    x_root;
+	clampRight = 0;
+	clampLeft = 1;
 	clampDX = 0;
-        action = 1;
+	action = 1;
     }
     if (clampBottom) {
-        int         delta = y_root - dragy - dragHeight;
-        if (dragHeight + delta < MINHEIGHT) {
-            delta = MINHEIGHT - dragHeight;
-            clampBottom = 0;
-        }
-        dragHeight += delta;
-        action = 1;
+	int         delta = y_root - dragy - dragHeight;
+	if (dragHeight + delta < MINHEIGHT) {
+	    delta = MINHEIGHT - dragHeight;
+	    clampBottom = 0;
+	}
+	dragHeight += delta;
+	action = 1;
     }
     else if (y_root >= dragy + dragHeight) {
-        dragy = origy;
-        dragHeight = 1 + y_root - dragy;
-        clampTop = 0;
-        clampBottom = 1;
+	dragy = origy;
+	dragHeight = 1 + y_root - dragy;
+	clampTop = 0;
+	clampBottom = 1;
 	clampDY = 0;
-        action = 1;
+	action = 1;
     }
     if (clampRight) {
-        int         delta = x_root - dragx - dragWidth;
-        if (dragWidth + delta < MINWIDTH) {
-            delta = MINWIDTH - dragWidth;
-            clampRight = 0;
-        }
-        dragWidth += delta;
-        action = 1;
+	int         delta = x_root - dragx - dragWidth;
+	if (dragWidth + delta < MINWIDTH) {
+	    delta = MINWIDTH - dragWidth;
+	    clampRight = 0;
+	}
+	dragWidth += delta;
+	action = 1;
     }
     else if (x_root >= dragx + dragWidth) {
-        dragx = origx;
-        dragWidth = 1 + x_root - origx;
-        clampLeft = 0;
-        clampRight = 1;
+	dragx = origx;
+	dragWidth = 1 + x_root - origx;
+	clampLeft = 0;
+	clampRight = 1;
 	clampDX = 0;
-        action = 1;
+	action = 1;
     }
 
     if (action) {
-        ConstrainSize (tmp_win, &dragWidth, &dragHeight);
-        if (clampLeft)
-            dragx = origx + origWidth - dragWidth;
-        if (clampTop)
-            dragy = origy + origHeight - dragHeight;
-        MoveOutline(Scr->Root,
-            dragx - tmp_win->frame_bw,
-            dragy - tmp_win->frame_bw,
-            dragWidth + 2 * tmp_win->frame_bw,
-            dragHeight + 2 * tmp_win->frame_bw,
+	ConstrainSize (tmp_win, &dragWidth, &dragHeight);
+	if (clampLeft)
+	    dragx = origx + origWidth - dragWidth;
+	if (clampTop)
+	    dragy = origy + origHeight - dragHeight;
+	MoveOutline(Scr->Root,
+	    dragx - tmp_win->frame_bw,
+	    dragy - tmp_win->frame_bw,
+	    dragWidth + 2 * tmp_win->frame_bw,
+	    dragHeight + 2 * tmp_win->frame_bw,
 	    tmp_win->frame_bw, tmp_win->title_height);
     }
 
@@ -392,10 +382,7 @@ TwmWindow *tmp_win;
  */
 
 void
-DoResize(x_root, y_root, tmp_win)
-int x_root;
-int y_root;
-TwmWindow *tmp_win;
+DoResize(int x_root, int y_root, TwmWindow *tmp_win)
 {
     int action;
 
@@ -405,95 +392,95 @@ TwmWindow *tmp_win;
     y_root -= clampDY;
 
     if (clampTop) {
-        int         delta = y_root - dragy;
-        if (dragHeight - delta < MINHEIGHT) {
-            delta = dragHeight - MINHEIGHT;
-            clampTop = 0;
-        }
-        dragy += delta;
-        dragHeight -= delta;
-        action = 1;
+	int         delta = y_root - dragy;
+	if (dragHeight - delta < MINHEIGHT) {
+	    delta = dragHeight - MINHEIGHT;
+	    clampTop = 0;
+	}
+	dragy += delta;
+	dragHeight -= delta;
+	action = 1;
     }
     else if (y_root <= dragy/* ||
-             y_root == findRootInfo(root)->rooty*/) {
-        dragy = y_root;
-        dragHeight = origy + origHeight -
-            y_root;
-        clampBottom = 0;
-        clampTop = 1;
+	     y_root == findRootInfo(root)->rooty*/) {
+	dragy = y_root;
+	dragHeight = origy + origHeight -
+	    y_root;
+	clampBottom = 0;
+	clampTop = 1;
 	clampDY = 0;
-        action = 1;
+	action = 1;
     }
     if (clampLeft) {
-        int         delta = x_root - dragx;
-        if (dragWidth - delta < MINWIDTH) {
-            delta = dragWidth - MINWIDTH;
-            clampLeft = 0;
-        }
-        dragx += delta;
-        dragWidth -= delta;
-        action = 1;
+	int         delta = x_root - dragx;
+	if (dragWidth - delta < MINWIDTH) {
+	    delta = dragWidth - MINWIDTH;
+	    clampLeft = 0;
+	}
+	dragx += delta;
+	dragWidth -= delta;
+	action = 1;
     }
     else if (x_root <= dragx/* ||
-             x_root == findRootInfo(root)->rootx*/) {
-        dragx = x_root;
-        dragWidth = origx + origWidth -
-            x_root;
-        clampRight = 0;
-        clampLeft = 1;
+	     x_root == findRootInfo(root)->rootx*/) {
+	dragx = x_root;
+	dragWidth = origx + origWidth -
+	    x_root;
+	clampRight = 0;
+	clampLeft = 1;
 	clampDX = 0;
-        action = 1;
+	action = 1;
     }
     if (clampBottom) {
-        int         delta = y_root - dragy - dragHeight;
-        if (dragHeight + delta < MINHEIGHT) {
-            delta = MINHEIGHT - dragHeight;
-            clampBottom = 0;
-        }
-        dragHeight += delta;
-        action = 1;
+	int         delta = y_root - dragy - dragHeight;
+	if (dragHeight + delta < MINHEIGHT) {
+	    delta = MINHEIGHT - dragHeight;
+	    clampBottom = 0;
+	}
+	dragHeight += delta;
+	action = 1;
     }
     else if (y_root >= dragy + dragHeight - 1/* ||
-           y_root == findRootInfo(root)->rooty
-           + findRootInfo(root)->rootheight - 1*/) {
-        dragy = origy;
-        dragHeight = 1 + y_root - dragy;
-        clampTop = 0;
-        clampBottom = 1;
+	   y_root == findRootInfo(root)->rooty
+	   + findRootInfo(root)->rootheight - 1*/) {
+	dragy = origy;
+	dragHeight = 1 + y_root - dragy;
+	clampTop = 0;
+	clampBottom = 1;
 	clampDY = 0;
-        action = 1;
+	action = 1;
     }
     if (clampRight) {
-        int         delta = x_root - dragx - dragWidth;
-        if (dragWidth + delta < MINWIDTH) {
-            delta = MINWIDTH - dragWidth;
-            clampRight = 0;
-        }
-        dragWidth += delta;
-        action = 1;
+	int         delta = x_root - dragx - dragWidth;
+	if (dragWidth + delta < MINWIDTH) {
+	    delta = MINWIDTH - dragWidth;
+	    clampRight = 0;
+	}
+	dragWidth += delta;
+	action = 1;
     }
     else if (x_root >= dragx + dragWidth - 1/* ||
-             x_root == findRootInfo(root)->rootx +
-             findRootInfo(root)->rootwidth - 1*/) {
-        dragx = origx;
-        dragWidth = 1 + x_root - origx;
-        clampLeft = 0;
-        clampRight = 1;
+	     x_root == findRootInfo(root)->rootx +
+	     findRootInfo(root)->rootwidth - 1*/) {
+	dragx = origx;
+	dragWidth = 1 + x_root - origx;
+	clampLeft = 0;
+	clampRight = 1;
 	clampDX = 0;
-        action = 1;
+	action = 1;
     }
 
     if (action) {
-        ConstrainSize (tmp_win, &dragWidth, &dragHeight);
-        if (clampLeft)
-            dragx = origx + origWidth - dragWidth;
-        if (clampTop)
-            dragy = origy + origHeight - dragHeight;
-        MoveOutline(Scr->Root,
-            dragx - tmp_win->frame_bw,
-            dragy - tmp_win->frame_bw,
-            dragWidth + 2 * tmp_win->frame_bw,
-            dragHeight + 2 * tmp_win->frame_bw,
+	ConstrainSize (tmp_win, &dragWidth, &dragHeight);
+	if (clampLeft)
+	    dragx = origx + origWidth - dragWidth;
+	if (clampTop)
+	    dragy = origy + origHeight - dragHeight;
+	MoveOutline(Scr->Root,
+	    dragx - tmp_win->frame_bw,
+	    dragy - tmp_win->frame_bw,
+	    dragWidth + 2 * tmp_win->frame_bw,
+	    dragHeight + 2 * tmp_win->frame_bw,
 	    tmp_win->frame_bw, tmp_win->title_height);
     }
 
@@ -514,17 +501,14 @@ TwmWindow *tmp_win;
  */
 
 void
-DisplaySize(tmp_win, width, height)
-TwmWindow *tmp_win;
-int width;
-int height;
+DisplaySize(TwmWindow *tmp_win, int width, int height)
 {
     char str[100];
     int dwidth;
     int dheight;
 
     if (last_width == width && last_height == height)
-        return;
+	return;
 
     last_width = width;
     last_height = height;
@@ -549,14 +533,14 @@ int height;
 
     if (tmp_win->hints.flags & PResizeInc)
     {
-        dwidth /= tmp_win->hints.width_inc;
-        dheight /= tmp_win->hints.height_inc;
+	dwidth /= tmp_win->hints.width_inc;
+	dheight /= tmp_win->hints.height_inc;
     }
 
     (void) sprintf (str, " %4d x %-4d ", dwidth, dheight);
     XRaiseWindow(dpy, Scr->SizeWindow);
     MyFont_ChangeGC(Scr->DefaultC.fore, Scr->DefaultC.back, &Scr->SizeFont);
-    MyFont_DrawImageString (dpy, Scr->SizeWindow, &Scr->SizeFont, 
+    MyFont_DrawImageString (dpy, Scr->SizeWindow, &Scr->SizeFont,
 			    Scr->NormalGC, Scr->SizeStringOffset,
 			    Scr->SizeFont.ascent + SIZE_VINDENT,
 			    str, 13);
@@ -571,7 +555,7 @@ int height;
  */
 
 void
-EndResize()
+EndResize(void)
 {
     TwmWindow *tmp_win;
 
@@ -587,8 +571,8 @@ EndResize()
     ConstrainSize (tmp_win, &dragWidth, &dragHeight);
 
     if (dragWidth != tmp_win->frame_width ||
-        dragHeight != tmp_win->frame_height)
-            tmp_win->zoomed = ZOOM_NONE;
+	dragHeight != tmp_win->frame_height)
+	    tmp_win->zoomed = ZOOM_NONE;
 
     SetupWindow (tmp_win, dragx - tmp_win->frame_bw, dragy - tmp_win->frame_bw,
 		 dragWidth, dragHeight, -1);
@@ -601,11 +585,11 @@ EndResize()
 	tmp_win->iconmgrp->width = (int) ((dragWidth *
 					   (long) tmp_win->iconmgrp->columns)
 					  / ncols);
-        PackIconManager(tmp_win->iconmgrp);
+	PackIconManager(tmp_win->iconmgrp);
     }
 
     if (!Scr->NoRaiseResize)
-        XRaiseWindow(dpy, tmp_win->frame);
+	XRaiseWindow(dpy, tmp_win->frame);
 
     UninstallRootColormap();
 
@@ -613,8 +597,7 @@ EndResize()
 }
 
 void
-MenuEndResize(tmp_win)
-TwmWindow *tmp_win;
+MenuEndResize(TwmWindow *tmp_win)
 {
     MoveOutline(Scr->Root, 0, 0, 0, 0, 0, 0);
     XUnmapWindow(dpy, Scr->SizeWindow);
@@ -637,8 +620,7 @@ TwmWindow *tmp_win;
  */
 
 void
-AddEndResize(tmp_win)
-TwmWindow *tmp_win;
+AddEndResize(TwmWindow *tmp_win)
 {
 
 #ifdef DEBUG
@@ -660,12 +642,10 @@ TwmWindow *tmp_win;
  *
  *      The general algorithm, especially the aspect ratio stuff, is
  *      borrowed from uwm's CheckConsistency routine.
- * 
+ *
  ***********************************************************************/
 void
-ConstrainSize (tmp_win, widthp, heightp)
-    TwmWindow *tmp_win;
-    int *widthp, *heightp;
+ConstrainSize (TwmWindow *tmp_win, int *widthp, int *heightp)
 {
 #define makemult(a,b) ((b==1) ? (a) : (((int)((a)/(b))) * (b)) )
 #define _min(a,b) (((a) < (b)) ? (a) : (b))
@@ -678,13 +658,13 @@ ConstrainSize (tmp_win, widthp, heightp)
     dheight -= tmp_win->title_height;
 
     if (tmp_win->hints.flags & PMinSize) {
-        minWidth = tmp_win->hints.min_width;
-        minHeight = tmp_win->hints.min_height;
+	minWidth = tmp_win->hints.min_width;
+	minHeight = tmp_win->hints.min_height;
     } else if (tmp_win->hints.flags & PBaseSize) {
-        minWidth = tmp_win->hints.base_width;
-        minHeight = tmp_win->hints.base_height;
+	minWidth = tmp_win->hints.base_width;
+	minHeight = tmp_win->hints.base_height;
     } else
-        minWidth = minHeight = 1;
+	minWidth = minHeight = 1;
 
     if (tmp_win->hints.flags & PBaseSize) {
 	baseWidth = tmp_win->hints.base_width;
@@ -697,18 +677,18 @@ ConstrainSize (tmp_win, widthp, heightp)
 
 
     if (tmp_win->hints.flags & PMaxSize) {
-        maxWidth = _min (Scr->MaxWindowWidth, tmp_win->hints.max_width);
-        maxHeight = _min (Scr->MaxWindowHeight, tmp_win->hints.max_height);
+	maxWidth = _min (Scr->MaxWindowWidth, tmp_win->hints.max_width);
+	maxHeight = _min (Scr->MaxWindowHeight, tmp_win->hints.max_height);
     } else {
-        maxWidth = Scr->MaxWindowWidth;
+	maxWidth = Scr->MaxWindowWidth;
 	maxHeight = Scr->MaxWindowHeight;
     }
 
     if (tmp_win->hints.flags & PResizeInc) {
-        xinc = tmp_win->hints.width_inc;
-        yinc = tmp_win->hints.height_inc;
+	xinc = tmp_win->hints.width_inc;
+	yinc = tmp_win->hints.height_inc;
     } else
-        xinc = yinc = 1;
+	xinc = yinc = 1;
 
     /*
      * First, clamp to min and max values
@@ -746,36 +726,36 @@ ConstrainSize (tmp_win, widthp, heightp)
      *
      * minAspectX * dheight > minAspectY * dwidth
      * maxAspectX * dheight < maxAspectY * dwidth
-     * 
+     *
      */
-    
+
     if (tmp_win->hints.flags & PAspect)
     {
-        if (minAspectX * dheight > minAspectY * dwidth)
-        {
-            delta = makemult(minAspectX * dheight / minAspectY - dwidth,
-                             xinc);
-            if (dwidth + delta <= maxWidth) dwidth += delta;
-            else
-            {
-                delta = makemult(dheight - dwidth*minAspectY/minAspectX,
-                                 yinc);
-                if (dheight - delta >= minHeight) dheight -= delta;
-            }
-        }
+	if (minAspectX * dheight > minAspectY * dwidth)
+	{
+	    delta = makemult(minAspectX * dheight / minAspectY - dwidth,
+			     xinc);
+	    if (dwidth + delta <= maxWidth) dwidth += delta;
+	    else
+	    {
+		delta = makemult(dheight - dwidth*minAspectY/minAspectX,
+				 yinc);
+		if (dheight - delta >= minHeight) dheight -= delta;
+	    }
+	}
 
-        if (maxAspectX * dheight < maxAspectY * dwidth)
-        {
-            delta = makemult(dwidth * maxAspectY / maxAspectX - dheight,
-                             yinc);
-            if (dheight + delta <= maxHeight) dheight += delta;
-            else
-            {
-                delta = makemult(dwidth - maxAspectX*dheight/maxAspectY,
-                                 xinc);
-                if (dwidth - delta >= minWidth) dwidth -= delta;
-            }
-        }
+	if (maxAspectX * dheight < maxAspectY * dwidth)
+	{
+	    delta = makemult(dwidth * maxAspectY / maxAspectX - dheight,
+			     yinc);
+	    if (dheight + delta <= maxHeight) dheight += delta;
+	    else
+	    {
+		delta = makemult(dwidth - maxAspectX*dheight/maxAspectY,
+				 xinc);
+		if (dwidth - delta >= minWidth) dwidth -= delta;
+	    }
+	}
     }
 
 
@@ -814,17 +794,15 @@ ConstrainSize (tmp_win, widthp, heightp)
  ***********************************************************************
  */
 
-void SetupWindow (tmp_win, x, y, w, h, bw)
-    TwmWindow *tmp_win;
-    int x, y, w, h, bw;
+void
+SetupWindow (TwmWindow *tmp_win, int x, int y, int w, int h, int bw)
 {
     SetupFrame (tmp_win, x, y, w, h, bw, False);
 }
 
-void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
-    TwmWindow *tmp_win;
-    int x, y, w, h, bw;
-    Bool sendEvent;			/* whether or not to force a send */
+void
+SetupFrame (TwmWindow *tmp_win, int x, int y, int w, int h, int bw,
+	    Bool sendEvent)
 {
     XEvent client_event;
     XWindowChanges frame_wc, xwc;
@@ -846,7 +824,7 @@ void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
 
     if (tmp_win->iconmgr) {
 	tmp_win->iconmgrp->width = w;
-        h = tmp_win->iconmgrp->height + tmp_win->title_height;
+	h = tmp_win->iconmgrp->height + tmp_win->title_height;
     }
 
     /*
@@ -873,10 +851,10 @@ void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
 	{
 	    xwc.width = title_width;
 	    if (tmp_win->frame_height != h ||
-	    	tmp_win->frame_width != w ||
+		tmp_win->frame_width != w ||
 		tmp_win->frame_bw != bw ||
-	    	title_width != tmp_win->title_width)
-	    	reShape = TRUE;
+		title_width != tmp_win->title_width)
+		reShape = TRUE;
 	}
 	else
 	{
@@ -895,7 +873,7 @@ void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
 	    tmp_win->title_y = xwc.y = -bw;
 	    xwcm |= (CWX | CWY | CWBorderWidth);
 	}
-	
+
 	XConfigureWindow(dpy, tmp_win->title_w, xwcm, &xwc);
     }
 
@@ -911,7 +889,7 @@ void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
     XMoveResizeWindow (dpy, tmp_win->w, 0, tmp_win->title_height,
 		       w, h - tmp_win->title_height);
 
-    /* 
+    /*
      * fix up frame and assign size/location values in tmp_win
      */
     frame_mask = 0;
@@ -933,15 +911,15 @@ void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
     {
 	xwc.width = (tmp_win->rightx - tmp_win->highlightx);
 	if (Scr->TBInfo.nright > 0) xwc.width -= Scr->TitlePadding;
-        if (xwc.width <= 0) {
-            xwc.x = Scr->MyDisplayWidth;	/* move offscreen */
-            xwc.width = 1;
-        } else {
-            xwc.x = tmp_win->highlightx;
-        }
+	if (xwc.width <= 0) {
+	    xwc.x = Scr->MyDisplayWidth;	/* move offscreen */
+	    xwc.width = 1;
+	} else {
+	    xwc.x = tmp_win->highlightx;
+	}
 
-        xwcm = CWX | CWWidth;
-        XConfigureWindow(dpy, tmp_win->hilite_w, xwcm, &xwc);
+	xwcm = CWX | CWWidth;
+	XConfigureWindow(dpy, tmp_win->hilite_w, xwcm, &xwc);
     }
 
     if (HasShape && reShape) {
@@ -950,22 +928,22 @@ void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
 
     if (sendEvent)
     {
-        client_event.type = ConfigureNotify;
-        client_event.xconfigure.display = dpy;
-        client_event.xconfigure.event = tmp_win->w;
-        client_event.xconfigure.window = tmp_win->w;
-        client_event.xconfigure.x = (x + tmp_win->frame_bw - tmp_win->old_bw);
-        client_event.xconfigure.y = (y + tmp_win->frame_bw +
+	client_event.type = ConfigureNotify;
+	client_event.xconfigure.display = dpy;
+	client_event.xconfigure.event = tmp_win->w;
+	client_event.xconfigure.window = tmp_win->w;
+	client_event.xconfigure.x = (x + tmp_win->frame_bw - tmp_win->old_bw);
+	client_event.xconfigure.y = (y + tmp_win->frame_bw +
 				     tmp_win->title_height - tmp_win->old_bw);
-        client_event.xconfigure.width = tmp_win->frame_width;
-        client_event.xconfigure.height = tmp_win->frame_height -
-                tmp_win->title_height;
-        client_event.xconfigure.border_width = tmp_win->old_bw;
-        /* Real ConfigureNotify events say we're above title window, so ... */
+	client_event.xconfigure.width = tmp_win->frame_width;
+	client_event.xconfigure.height = tmp_win->frame_height -
+		tmp_win->title_height;
+	client_event.xconfigure.border_width = tmp_win->old_bw;
+	/* Real ConfigureNotify events say we're above title window, so ... */
 	/* what if we don't have a title ????? */
-        client_event.xconfigure.above = tmp_win->frame;
-        client_event.xconfigure.override_redirect = False;
-        XSendEvent(dpy, tmp_win->w, False, StructureNotifyMask, &client_event);
+	client_event.xconfigure.above = tmp_win->frame;
+	client_event.xconfigure.override_redirect = False;
+	XSendEvent(dpy, tmp_win->w, False, StructureNotifyMask, &client_event);
     }
 }
 
@@ -986,9 +964,7 @@ void SetupFrame (tmp_win, x, y, w, h, bw, sendEvent)
  */
 
 void
-fullzoom(tmp_win,flag)
-TwmWindow *tmp_win;
-int flag;
+fullzoom(TwmWindow *tmp_win, int flag)
 {
     Window      junkRoot;
     unsigned int junkbw, junkDepth;
@@ -1023,59 +999,59 @@ int flag;
 	tmp_win->zoomed = flag;
 	frame_bw_times_2 = 2*tmp_win->frame_bw;
 
-        switch (flag)
-        {
-        case ZOOM_NONE:
-            break;
-        case F_ZOOM:
-            dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
-            dragy=basey;
-            break;
-        case F_HORIZOOM:
-            dragx = basex;
-            dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
-            break;
-        case F_FULLZOOM:
-            dragx = basex;
-            dragy = basey;
-            dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
-            dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
-            break;
-        case F_LEFTZOOM:
-            dragx = basex;
-            dragy = basey;
-            dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
-            dragWidth = Scr->MyDisplayWidth/2 - frame_bw_times_2;
-            break;
-        case F_RIGHTZOOM:
-            dragx = basex + Scr->MyDisplayWidth/2;
-            dragy = basey;
-            dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
-            dragWidth = Scr->MyDisplayWidth/2 - frame_bw_times_2;
-            break;
-        case F_TOPZOOM:
-            dragx = basex;
-            dragy = basey;
-            dragHeight = Scr->MyDisplayHeight/2 - frame_bw_times_2;
-            dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
-            break;
-        case F_BOTTOMZOOM:
-            dragx = basex;
-            dragy = basey + Scr->MyDisplayHeight/2;
-            dragHeight = Scr->MyDisplayHeight/2 - frame_bw_times_2;
-            dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
-            break;
+	switch (flag)
+	{
+	case ZOOM_NONE:
+	    break;
+	case F_ZOOM:
+	    dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
+	    dragy=basey;
+	    break;
+	case F_HORIZOOM:
+	    dragx = basex;
+	    dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
+	    break;
+	case F_FULLZOOM:
+	    dragx = basex;
+	    dragy = basey;
+	    dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
+	    dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
+	    break;
+	case F_LEFTZOOM:
+	    dragx = basex;
+	    dragy = basey;
+	    dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
+	    dragWidth = Scr->MyDisplayWidth/2 - frame_bw_times_2;
+	    break;
+	case F_RIGHTZOOM:
+	    dragx = basex + Scr->MyDisplayWidth/2;
+	    dragy = basey;
+	    dragHeight = Scr->MyDisplayHeight - frame_bw_times_2;
+	    dragWidth = Scr->MyDisplayWidth/2 - frame_bw_times_2;
+	    break;
+	case F_TOPZOOM:
+	    dragx = basex;
+	    dragy = basey;
+	    dragHeight = Scr->MyDisplayHeight/2 - frame_bw_times_2;
+	    dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
+	    break;
+	case F_BOTTOMZOOM:
+	    dragx = basex;
+	    dragy = basey + Scr->MyDisplayHeight/2;
+	    dragHeight = Scr->MyDisplayHeight/2 - frame_bw_times_2;
+	    dragWidth = Scr->MyDisplayWidth - frame_bw_times_2;
+	    break;
 	case F_TOTALZOOM:
 	    dragx = -tmp_win->frame_bw;
 	    dragy = -tmp_win->title_height - tmp_win->frame_bw;
 	    dragHeight = Scr->MyDisplayHeight + tmp_win->title_height;
 	    dragWidth = Scr->MyDisplayWidth;
 	    break;
-         }
+	 }
     }
 
     if (!Scr->NoRaiseResize)
-        XRaiseWindow(dpy, tmp_win->frame);
+	XRaiseWindow(dpy, tmp_win->frame);
 
     if (flag != F_TOTALZOOM)
 	ConstrainSize(tmp_win, &dragWidth, &dragHeight);
@@ -1086,8 +1062,7 @@ int flag;
 }
 
 void
-SetFrameShape (tmp)
-    TwmWindow *tmp;
+SetFrameShape (TwmWindow *tmp)
 {
     /*
      * see if the titlebar needs to move
@@ -1158,7 +1133,7 @@ SetFrameShape (tmp)
 				     newClip, 2, ShapeSet, YXBanded);
 	} else {
 	    (void) XShapeCombineMask (dpy, tmp->frame, ShapeBounding, 0, 0,
- 				      None, ShapeSet);
+				      None, ShapeSet);
 	    (void) XShapeCombineMask (dpy, tmp->frame, ShapeClip, 0, 0,
 				      None, ShapeSet);
 	}
@@ -1167,7 +1142,7 @@ SetFrameShape (tmp)
 
 /*
  * Squeezed Title:
- * 
+ *
  *                         tmp->title_x
  *                   0     |
  *  tmp->title_y   ........+--------------+.........  -+,- tmp->frame_bw
@@ -1183,10 +1158,10 @@ SetFrameShape (tmp)
  *                 | |                           | |
  *                 | +---------------------------+ |
  *                 +-------------------------------+
- * 
- * 
+ *
+ *
  * Unsqueezed Title:
- * 
+ *
  *                 tmp->title_x
  *                 | 0
  *  tmp->title_y   +-------------------------------+  -+,tmp->frame_bw
@@ -1202,11 +1177,11 @@ SetFrameShape (tmp)
  *                 | |                           | |
  *                 | +---------------------------+ |
  *                 +-------------------------------+
- * 
- * 
- * 
+ *
+ *
+ *
  * Dimensions and Positions:
- * 
+ *
  *     frame origin                (0, 0)
  *     frame upper left border     (-tmp->frame_bw, -tmp->frame_bw)
  *     frame size w/o border       tmp->frame_width , tmp->frame_height
@@ -1216,7 +1191,7 @@ SetFrameShape (tmp)
  *     title origin w/o border     (tmp->title_x, tmp->title_y)
  *     client origin               (0, Scr->TitleHeight + tmp->frame_bw)
  *     client size                 tmp->attr.width , tmp->attr.height
- * 
+ *
  * When shaping, need to remember that the width and height of rectangles
  * are really deltax and deltay to lower right handle corner, so they need
  * to have -1 subtracted from would normally be the actual extents.
