@@ -25,7 +25,7 @@ other dealings in this Software without prior written authorization
 from The Open Group.
 
 */
-/* $XFree86: xc/programs/xdm/dm.h,v 3.35 2006/01/09 15:01:03 dawes Exp $ */
+/* $XFree86: xc/programs/xdm/dm.h,v 3.36 2006/12/10 15:58:34 tsi Exp $ */
 
 /*
  * xdm - display manager daemon
@@ -392,6 +392,9 @@ extern void RemoveDisplay (struct display *old);
 extern void ParseDisplay (char *source, DisplayType *acceptableTypes, int numAcceptable);
 
 /* in netaddr.c */
+#ifdef DEBUG
+extern void PrintSockAddr (XdmcpNetaddr addr, int len);
+#endif
 extern char *NetaddrAddress(XdmcpNetaddr netaddrp, int *lenp);
 extern char *NetaddrPort(XdmcpNetaddr netaddrp, int *lenp);
 extern int ConvertAddr (XdmcpNetaddr saddr, int *len, char **addr);
